==> utils-0.6.0.tgz: package/lib/es2015.js <==
import { execSync } from 'child_process';
import chalk from 'chalk';
import spawn from 'cross-spawn';
import open from 'open';
import fs from 'fs';
import path from 'path';
import isGlob from 'is-glob';
import globSync from 'tiny-glob/sync';

// https://github.com/sindresorhus/open#app
const OSX_CHROME = 'google chrome';
var Action;
(function (Action) {
    Action[Action["NONE"] = 0] = "NONE";
    Action[Action["BROWSER"] = 1] = "BROWSER";
    Action[Action["SCRIPT"] = 2] = "SCRIPT";
})(Action || (Action = {}));
function getBrowserEnv() {
    // Attempt to honor this environment variable.
    // It is specific to the operating system.
    // See https://github.com/sindresorhus/open#app for documentation.
    const value = process.env.BROWSER;
    const args = process.env.BROWSER_ARGS
        ? process.env.BROWSER_ARGS.split(' ')
        : [];
    let action;
    if (!value) {
        // Default.
        action = Action.BROWSER;
    }
    else if (value.toLowerCase().endsWith('.js')) {
        action = Action.SCRIPT;
    }
    else if (value.toLowerCase() === 'none') {
        action = Action.NONE;
    }
    else {
        action = Action.BROWSER;
    }
    return { action, value, args };
}
function executeNodeScript(scriptPath, url) {
    const extraArgs = process.argv.slice(2);
    const child = spawn('node', [scriptPath, ...extraArgs, url], {
        stdio: 'inherit',
    });
    child.on('close', (code) => {
        if (code !== 0) {
            console.log();
            console.log(chalk.red('The script specified as BROWSER environment variable failed.'));
            console.log(`${chalk.cyan(scriptPath)} exited with code ${code}.\n`);
        }
    });
    return true;
}
function startBrowserProcess(browser, url, args) {
    // If we're on OS X, the user hasn't specifically
    // requested a different browser, we can try opening
    // Chrome with AppleScript. This lets us reuse an
    // existing tab when possible instead of creating a new one.
    const shouldTryOpenChromeWithAppleScript = process.platform === 'darwin' &&
        (typeof browser !== 'string' || browser === OSX_CHROME);
    if (shouldTryOpenChromeWithAppleScript) {
        try {
            // Try our best to reuse existing tab
            // on OS X Google Chrome with AppleScript
            execSync('ps cax | grep "Google Chrome"');
            execSync('osascript ../openChrome.applescript "' + encodeURI(url) + '"', {
                cwd: __dirname,
                stdio: 'ignore',
            });
            return true;
        }
        catch (_a) {
            // Ignore errors.
        }
    }
    // Another special case: on OS X, check if BROWSER has been set to "open".
    // In this case, instead of passing `open` to `opn` (which won't work),
    // just ignore it (thus ensuring the intended behavior, i.e. opening the system browser):
    // https://github.com/facebook/create-react-app/pull/1690#issuecomment-283518768
    if (process.platform === 'darwin' && browser === 'open') {
        browser = undefined;
    }
    // If there are arguments, they must be passed as array with the browser
    if (typeof browser === 'string' && args.length > 0) {
        browser = [browser, ...args];
    }
    // Fallback to open
    // (It will always open new tab)
    // tslint:disable-next-line no-try-promise
    try {
        const options = { app: browser, wait: false };
        // eslint-disable-next-line @typescript-eslint/no-empty-function
        open(url, options).catch(() => { }); // Prevent `unhandledRejection` error.
        return true;
    }
    catch (_b) {
        return false;
    }
}
/**
 * Reads the BROWSER environment variable and decides what to do with it. Returns
 * true if it opened a browser or ran a node.js script, otherwise false.
 */
function openBrowser(url) {
    const { action, value, args } = getBrowserEnv();
    switch (action) {
        case Action.NONE:
            // Special case: BROWSER="none" will prevent opening completely.
            return false;
        case Action.SCRIPT:
            return executeNodeScript(value, url);
        case Action.BROWSER:
            return startBrowserProcess(value, url, args);
        default:
            throw new Error('Not implemented.');
    }
}

const DEV = 'development';
const PROD = 'production';
const { NODE_ENV = DEV } = process.env;
const __DEV__ = NODE_ENV === DEV;
const __PROD__ = NODE_ENV === PROD;
const NODE_MODULES_REG = /[/\\]node_modules[/\\]/;
const CWD = process.cwd();
// eslint-disable-next-line node/no-deprecated-api
const EXTENSIONS = ['.ts', '.tsx', ...Object.keys(require.extensions)];

const tryPkg = (pkg) => {
    try {
        return require.resolve(pkg);
    }
    catch (_a) { }
};
const tryRequirePkg = (pkg) => {
    try {
        // eslint-disable-next-line @typescript-eslint/no-require-imports, @typescript-eslint/no-unsafe-return
        return require(pkg);
    }
    catch (_a) { }
};
const isPkgAvailable = (pkg) => !!tryPkg(pkg);
const isTsAvailable = isPkgAvailable('typescript');
const isAngularAvailable = isPkgAvailable('@angular/core');
const isMdxAvailable = isPkgAvailable('@mdx/mdx') || isPkgAvailable('@mdx/react');
const isReactAvailable = isPkgAvailable('react');
const isSvelteAvailable = isPkgAvailable('svelte');
const isVueAvailable = isPkgAvailable('vue');
const tryFile = (filePath, includeDir = false) => {
    if (typeof filePath === 'string') {
        return fs.existsSync(filePath) &&
            (includeDir || fs.statSync(filePath).isFile())
            ? filePath
            : '';
    }
    for (const file of filePath || []) {
        if (tryFile(file, includeDir)) {
            return file;
        }
    }
    return '';
};
const tryExtensions = (filepath, extensions = EXTENSIONS) => {
    const ext = [...extensions, ''].find(ext => tryFile(filepath + ext));
    return ext == null ? '' : filepath + ext;
};
const tryGlob = (paths, options = {}) => {
    const { absolute = true, baseDir = CWD } = typeof options === 'string' ? { baseDir: options } : options;
    return paths.reduce((acc, pkg) => [
        ...acc,
        ...(isGlob(pkg)
            ? globSync(pkg, {
                absolute,
                cwd: baseDir,
            })
            : [tryFile(path.resolve(baseDir, pkg), true)]),
    ].filter(Boolean), []);
};
const identify = (_) => !!_;
const findUp = (searchEntry, searchFile = 'package.json') => {
    console.assert(path.isAbsolute(searchEntry));
    if (!tryFile(searchEntry, true) ||
        (searchEntry !== CWD && !searchEntry.startsWith(CWD + path.sep))) {
        return '';
    }
    searchEntry = path.resolve(fs.statSync(searchEntry).isDirectory()
        ? searchEntry
        : path.resolve(searchEntry, '..'));
    do {
        const searched = tryFile(path.resolve(searchEntry, searchFile));
        if (searched) {
            return searched;
        }
        searchEntry = path.resolve(searchEntry, '..');
    } while (searchEntry === CWD || searchEntry.startsWith(CWD + path.sep));
    return '';
};
const arrayify = (...args) => args.reduce((arr, curr) => {
    arr.push(...(Array.isArray(curr) ? curr : [curr]));
    return arr;
}, []);

const pkg = tryRequirePkg(path.resolve('package.json')) || {};
const lernaConfig = tryRequirePkg(path.resolve('lerna.json')) || {};
const pkgsPath = lernaConfig.packages || pkg.workspaces || [];
const isMonorepo = Array.isArray(pkgsPath) && pkgsPath.length > 0;
const monorepoPkgs = isMonorepo ? tryGlob(pkgsPath) : [];

export { CWD, DEV, EXTENSIONS, NODE_ENV, NODE_MODULES_REG, PROD, __DEV__, __PROD__, arrayify, findUp, identify, isAngularAvailable, isMdxAvailable, isMonorepo, isPkgAvailable, isReactAvailable, isSvelteAvailable, isTsAvailable, isVueAvailable, monorepoPkgs, openBrowser, tryExtensions, tryFile, tryGlob, tryPkg, tryRequirePkg };

==> utils-0.7.0.tgz: package/lib/es2015.js <==
import { execSync } from 'child_process';
import chalk from 'chalk';
import spawn from 'cross-spawn';
import open from 'open';
import fs from 'fs';
import path from 'path';
import isGlob from 'is-glob';
import globSync from 'tiny-glob/sync';

// based on https://github.com/facebook/create-react-app/blob/master/packages/react-dev-utils/openBrowser.js
// https://github.com/sindresorhus/open#app
const OSX_CHROME = 'google chrome';
var Action;
(function (Action) {
    Action[Action["NONE"] = 0] = "NONE";
    Action[Action["BROWSER"] = 1] = "BROWSER";
    Action[Action["SCRIPT"] = 2] = "SCRIPT";
})(Action || (Action = {}));
function getBrowserEnv() {
    // Attempt to honor this environment variable.
    // It is specific to the operating system.
    // See https://github.com/sindresorhus/open#app for documentation.
    const value = process.env.BROWSER;
    const args = process.env.BROWSER_ARGS
        ? process.env.BROWSER_ARGS.split(' ')
        : [];
    let action;
    if (!value) {
        // Default.
        action = Action.BROWSER;
    }
    else if (value.toLowerCase().endsWith('.js')) {
        action = Action.SCRIPT;
    }
    else if (value.toLowerCase() === 'none') {
        action = Action.NONE;
    }
    else {
        action = Action.BROWSER;
    }
    return { action, value, args };
}
function executeNodeScript(scriptPath, url) {
    const extraArgs = process.argv.slice(2);
    const child = spawn('node', [scriptPath, ...extraArgs, url], {
        stdio: 'inherit',
    });
    child.on('close', (code) => {
        if (code !== 0) {
            console.log();
            console.log(chalk.red('The script specified as BROWSER environment variable failed.'));
            console.log(`${chalk.cyan(scriptPath)} exited with code ${code}.\n`);
        }
    });
    return true;
}
function startBrowserProcess(browser, url, args) {
    // If we're on OS X, the user hasn't specifically
    // requested a different browser, we can try opening
    // Chrome with AppleScript. This lets us reuse an
    // existing tab when possible instead of creating a new one.
    const shouldTryOpenChromeWithAppleScript = process.platform === 'darwin' &&
        (typeof browser !== 'string' || browser === OSX_CHROME);
    if (shouldTryOpenChromeWithAppleScript) {
        try {
            // Try our best to reuse existing tab
            // on OS X Google Chrome with AppleScript
            execSync('ps cax | grep "Google Chrome"');
            execSync('osascript ../openChrome.applescript "' + encodeURI(url) + '"', {
                cwd: __dirname,
                stdio: 'ignore',
            });
            return true;
        }
        catch (_a) {
            // Ignore errors.
        }
    }
    // Another special case: on OS X, check if BROWSER has been set to "open".
    // In this case, instead of passing `open` to `opn` (which won't work),
    // just ignore it (thus ensuring the intended behavior, i.e. opening the system browser):
    // https://github.com/facebook/create-react-app/pull/1690#issuecomment-283518768
    if (process.platform === 'darwin' && browser === 'open') {
        browser = undefined;
    }
    // Fallback to open
    // (It will always open new tab)
    // eslint-disable-next-line sonar/no-try-promise
    try {
        open(url, {
            app: browser
                ? {
                    name: browser,
                    arguments: args,
                }
                : undefined,
            wait: false,
        }).catch(() => { }); // eslint-disable-line @typescript-eslint/no-empty-function -- Prevent `unhandledRejection` error.
        return true;
    }
    catch (_b) {
        return false;
    }
}
/**
 * Reads the BROWSER environment variable and decides what to do with it. Returns
 * true if it opened a browser or ran a node.js script, otherwise false.
 */
function openBrowser(url) {
    const { action, value, args } = getBrowserEnv();
    switch (action) {
        case Action.NONE:
            // Special case: BROWSER="none" will prevent opening completely.
            return false;
        case Action.SCRIPT:
            return executeNodeScript(value, url);
        case Action.BROWSER:
            return startBrowserProcess(value, url, args);
        default:
            throw new Error('Not implemented.');
    }
}

const DEV = 'development';
const PROD = 'production';
const { NODE_ENV = DEV } = process.env;
const __DEV__ = NODE_ENV === DEV;
const __PROD__ = NODE_ENV === PROD;
const NODE_MODULES_REG = /[/\\]node_modules[/\\]/;
const CWD = process.cwd();
// eslint-disable-next-line node/no-deprecated-api, sonar/deprecation
const EXTENSIONS = ['.ts', '.tsx', ...Object.keys(require.extensions)];

const tryPkg = (pkg) => {
    try {
        return require.resolve(pkg);
    }
    catch (_a) { }
};
const tryRequirePkg = (pkg) => {
    try {
        // eslint-disable-next-line @typescript-eslint/no-require-imports, @typescript-eslint/no-unsafe-return
        return require(pkg);
    }
    catch (_a) { }
};
const isPkgAvailable = (pkg) => !!tryPkg(pkg);
const isTsAvailable = isPkgAvailable('typescript');
const isAngularAvailable = isPkgAvailable('@angular/core');
const isMdxAvailable = isPkgAvailable('@mdx/mdx') || isPkgAvailable('@mdx/react');
const isReactAvailable = isPkgAvailable('react');
const isSvelteAvailable = isPkgAvailable('svelte');
const isVueAvailable = isPkgAvailable('vue');
const tryFile = (filePath, includeDir = false) => {
    if (typeof filePath === 'string') {
        return fs.existsSync(filePath) &&
            (includeDir || fs.statSync(filePath).isFile())
            ? filePath
            : '';
    }
    for (const file of filePath || []) {
        if (tryFile(file, includeDir)) {
            return file;
        }
    }
    return '';
};
const tryExtensions = (filepath, extensions = EXTENSIONS) => {
    const ext = [...extensions, ''].find(ext => tryFile(filepath + ext));
    return ext == null ? '' : filepath + ext;
};
const tryGlob = (paths, options = {}) => {
    const { absolute = true, baseDir = CWD } = typeof options === 'string' ? { baseDir: options } : options;
    return paths.reduce((acc, pkg) => [
        ...acc,
        ...(isGlob(pkg)
            ? globSync(pkg, {
                absolute,
                cwd: baseDir,
            })
            : [tryFile(path.resolve(baseDir, pkg), true)]),
    ].filter(Boolean), []);
};
const identify = (_) => !!_;
const findUp = (searchEntry, searchFile = 'package.json') => {
    console.assert(path.isAbsolute(searchEntry));
    if (!tryFile(searchEntry, true) ||
        (searchEntry !== CWD && !searchEntry.startsWith(CWD + path.sep))) {
        return '';
    }
    searchEntry = path.resolve(fs.statSync(searchEntry).isDirectory()
        ? searchEntry
        : path.resolve(searchEntry, '..'));
    do {
        const searched = tryFile(path.resolve(searchEntry, searchFile));
        if (searched) {
            return searched;
        }
        searchEntry = path.resolve(searchEntry, '..');
    } while (searchEntry === CWD || searchEntry.startsWith(CWD + path.sep));
    return '';
};
const arrayify = (...args) => args.reduce((arr, curr) => {
    arr.push(...(Array.isArray(curr) ? curr : curr == null ? [] : [curr]));
    return arr;
}, []);

const pkg = tryRequirePkg(path.resolve('package.json')) || {};
const lernaConfig = tryRequirePkg(path.resolve('lerna.json')) || {};
const pkgsPath = lernaConfig.packages || pkg.workspaces || [];
const isMonorepo = Array.isArray(pkgsPath) && pkgsPath.length > 0;
const monorepoPkgs = isMonorepo ? tryGlob(pkgsPath) : [];

export { CWD, DEV, EXTENSIONS, NODE_ENV, NODE_MODULES_REG, PROD, __DEV__, __PROD__, arrayify, findUp, identify, isAngularAvailable, isMdxAvailable, isMonorepo, isPkgAvailable, isReactAvailable, isSvelteAvailable, isTsAvailable, isVueAvailable, monorepoPkgs, openBrowser, tryExtensions, tryFile, tryGlob, tryPkg, tryRequirePkg };
